@@ -3,12 +3,9 @@
 use strict;
 use warnings;
 use warnings qw(FATAL utf8); # Fatalize encoding glitches.
-use open     qw(:std :utf8); # Undeclared streams in UTF-8.
 
 use File::Spec;
 
-use File::Slurp::Tiny 'read_file';
-
 use Tree::DAG_Node;
 
 # ------------------------------------------------
